Module log

Module log 

log.* — Logging via tracing.

All Lua log calls are emitted under a lua tracing target with a script field so output can be filtered and attributed per script.

Environment access (env.*) is provided by mlua-batteries (std.env). Agent-specific functions (env.agent_id, env.project_root) are injected into the batteries-provided std.env table here.

Functions

register